@@ -152,12 +152,12 @@ def test_extra_type_args(capsys, rosbuilder, step, btype):
 
 @pytest.mark.parametrize("step", BUILD_STEPS)
 def test_command_prefix(capsys, rosbuilder, step):
-    run(rosbuilder("--clean"), {f"ROS_{step.upper()}_COMMAND_PREFIX": "COMMAND PREFIX"})
-    run(rosbuilder(), {f"ROS_{step.upper()}_COMMAND_PREFIX": "COMMAND PREFIX"})
+    run(rosbuilder("--clean"), {f"ROS_{step.upper()}_WRAPPER": "WRAPPING COMMAND"})
+    run(rosbuilder(), {f"ROS_{step.upper()}_WRAPPER": "WRAPPING COMMAND"})
     captured = capsys.readouterr()
     for test_step in BUILD_STEPS:
         assert bool(
-            re.search(f"(?m)^{cmdind}COMMAND PREFIX dh_auto_{test_step}", captured.out)
+            re.search(f"(?m)^{cmdind}WRAPPING COMMAND dh_auto_{test_step}", captured.out)
         ) == (test_step == step)
 
 
@@ -165,17 +165,17 @@ def test_command_prefix(capsys, rosbuilder, step):
 def test_type_command_prefix(capsys, rosbuilder, step, btype):
     run(
         rosbuilder("--clean"),
-        {f"ROS_{step.upper()}_{btype.upper()}_COMMAND_PREFIX": "COMMAND PREFIX"},
+        {f"ROS_{step.upper()}_{btype.upper()}_WRAPPER": "WRAPPING COMMAND"},
     )
     run(
         rosbuilder(),
-        {f"ROS_{step.upper()}_{btype.upper()}_COMMAND_PREFIX": "COMMAND PREFIX"},
+        {f"ROS_{step.upper()}_{btype.upper()}_WRAPPER": "WRAPPING COMMAND"},
     )
     captured = capsys.readouterr()
     for test_step, test_type in itertools.product(BUILD_STEPS, BUILD_TYPES):
         assert bool(
             re.search(
-                f"(?m)^{cmdind}COMMAND PREFIX dh_auto_{test_step} --sourcedir=foo_{test_type} ",
+                f"(?m)^{cmdind}WRAPPING COMMAND dh_auto_{test_step} --sourcedir=foo_{test_type} ",
                 captured.out,
             )
         ) == (test_step == step and test_type == btype)
